;; Generated package description from zenburn-theme.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "zenburn-theme" "2.9.0.0.20260601.26" "A low contrast color theme for Emacs." 'nil :commit "6453e5318ceceb70ce6dc1ea61009e864c937aca" :authors '(("Bozhidar Batsov" . "bozhidar@batsov.com")) :maintainer '("Bozhidar Batsov" . "bozhidar@batsov.com") :url "https://github.com/bbatsov/zenburn-emacs")
